AUTH_ADDRESS_REQUIRED = "AUTH_ADDRESS_REQUIRED"
AUTH_DENIED = "AUTH_DENIED"
PROXY_AUTH_ADDRESS_REQUIRED = "PROXY_AUTH_ADDRESS_REQUIRED"
PROXY_AUTH_DENIED = "PROXY_AUTH_DENIED"
NO_SOCKET = "NO_SOCKET"
PROXY_NO_SOCKET = "PROXY_NO_SOCKET"
AUTH_TIMEOUT = "AUTH_TIMEOUT"
CHALLENGE_TIMEOUT = "CHALLENGE_TIMEOUT"
ENCRYPTION_TIMEOUT = "ENCRYPTION_TIMEOUT"
FORWARDING_TIMEOUT = "FORWARDING_TIMEOUT"
